changeset 3642:2cef9d562af0

void* context added - it should keep the codec-specific stuff (struct ptr or HANDLE)
author arpi
date Fri, 21 Dec 2001 16:17:24 +0000
parents 33c560ffd3dc
children fb9fd7e2dd35
files libmpdemux/stheader.h
diffstat 1 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/libmpdemux/stheader.h	Fri Dec 21 02:09:34 2001 +0000
+++ b/libmpdemux/stheader.h	Fri Dec 21 16:17:24 2001 +0000
@@ -34,11 +34,12 @@
   int audio_in_minsize;
   int audio_out_minsize;
   // other codecs:
+  void* context; // codec-specific stuff (usually HANDLE or struct pointer)
 //  ac3_frame_t *ac3_frame;
-  void* ac3_frame;
+  void* ac3_frame;  // TODO: use *context
   int pcm_bswap;
 #ifdef HAVE_OGGVORBIS
-  struct ov_struct_st *ov; // should be assigned on init
+  struct ov_struct_st *ov; // should be assigned on init  TODO: use *context
 #endif
 } sh_audio_t;
 
@@ -65,6 +66,7 @@
   AVIStreamHeader video;
   BITMAPINFOHEADER *bih;   // in format
   BITMAPINFOHEADER o_bih; // out format
+  void* context; // codec-specific stuff (usually HANDLE or struct pointer)
   HIC hic;  // handle
 } sh_video_t;